<?php

namespace Drupal\acquia_dam;

/**
 * Create widen specific image url.
 */
final class EmbedCodeUrlBuilder {

  /**
   * Image formats available on the WIDEN end.
   */
  const AVAILABLE_IMAGE_FORMATS = [
    'gif',
    'jpg',
    'png',
    'web',
    'webp',
    'jpeg',
  ];

  /**
   * Converts image effect plugin configuration to query parameters.
   *
   * @param array $effects
   *   Array of effects from a particular style.
   *
   * @return array
   *   Query parameters for embed code URL.
   */
  public static function mapImageEffects(array $effects): array {
    $anchor_mapping = [
      'center-center' => 'c',
      'top' => 'n',
      'right-top' => 'ne',
      'right' => 'e',
      'right-bottom' => 'se',
      'bottom' => 's',
      'left-bottom' => 'sw',
      'left' => 'w',
      'left-top' => 'nw',
    ];
    $values = [];
    $values['format'] = 'web';

    foreach ($effects as $effect) {
      switch ($effect['id']) {
        case 'image_convert':
          if (in_array($effect['data']['extension'], self::AVAILABLE_IMAGE_FORMATS, TRUE)) {
            $values['format'] = $effect['data']['extension'];
          }
          break;

        case 'image_rotate':
          $values['r'] = $effect['data']['degrees'];
          if ($effect['data']['bgcolor'] !== "") {
            $values['color'] = str_replace('#', '', $effect['data']['bgcolor']);
          }
          break;

        case 'image_resize':
          $values['w'] = $effect['data']['width'];
          $values['h'] = $effect['data']['height'];
          break;

        case 'image_crop':
          $values['crop'] = 'yes';
          $values['k'] = $anchor_mapping[$effect['data']['anchor']];
          $values['w'] = $effect['data']['width'];
          $values['h'] = $effect['data']['height'];
          break;

        case 'image_scale':
          if ($effect['data']['width']) {
            $values['w'] = $effect['data']['width'];
          }
          if ($effect['data']['height']) {
            $values['h'] = $effect['data']['height'];
          }
          break;
      }
    }
    return $values;
  }

}
