<?php

declare(strict_types=1);

namespace Drupal\acquia_dam;

use Drupal\filter\FilterFormatInterface;
use Drupal\filter\FilterPluginCollection;

/**
 * Processes filter formats for appropriate allowed_html when using media_embed.
 */
final class FormatAllowedHtmlModifier {

  /**
   * Ensures the allowed_html setting for filter_html is correct.
   *
   * @param \Drupal\filter\FilterFormatInterface $filter_format
   *   The filter format.
   */
  public static function process(FilterFormatInterface $filter_format): void {
    $filters = $filter_format->filters();
    assert($filters instanceof FilterPluginCollection);
    if ($filters->has('media_embed') && $filters->has('filter_html')) {
      $filter_html = $filters->get('filter_html');
      $configuration = $filter_html->getConfiguration();

      // Explode the `allowed_html` values into an array.
      $restrictions = $filter_html->getHTMLRestrictions();
      $restrictions['allowed']['drupal-media']['data-embed-code-id'] = TRUE;
      $restrictions['allowed']['drupal-media']['data-entity-revision'] = TRUE;

      // Convert `allowed_html` back to a string and update the configuration.
      $configuration['settings']['allowed_html'] = self::allowedHtmlToString($restrictions['allowed']);
      $filter_format->setFilterConfig('filter_html', $configuration);
    }
  }

  /**
   * Converts the allowed elements/attributes array back to a string.
   *
   * @param array $allowed
   *   The allowed elements and attributes.
   *
   * @return string
   *   The allowed_html string.
   */
  private static function allowedHtmlToString(array $allowed): string {
    $filter_html_allowed = '';
    foreach ($allowed as $element => $attributes) {
      if ($element === '*') {
        continue;
      }
      $filter_html_allowed .= '<' . $element;
      if (is_array($attributes)) {
        $filter_html_allowed .= ' ' . implode(' ', array_keys($attributes));
      }
      $filter_html_allowed .= '> ';
    }
    return $filter_html_allowed;
  }

}
