<?php

namespace Drupal\acquia_dam\TwigExtension;

use Drupal\cohesion_templates\TwigExtension\TwigExtension;

/**
 * Fixes acquia-dam stream wrapper compatibility with Site Studio.
 *
 * The Site Studio TwigExtension strips domains from image style URLs.All Acquia
 * DAM assets are served from the DAM's CDN and must retain their domain name.
 */
class TwigCohesionImageStylesExtension extends TwigExtension {

  /**
   * {@inheritDoc}
   */
  public function cohesionImageStyle($file_uri, $image_style) {
    if (!str_starts_with($file_uri, 'acquia-dam://')) {
      parent::cohesionImageStyle($file_uri, $image_style);
    }
    if ($image_style instanceof \Twig_Markup) {
      $image_style = $image_style->__toString();
    }

    $file_uri = html_entity_decode(stripcslashes($file_uri));
    if (!\Drupal::service('stream_wrapper_manager')->isValidUri($file_uri)) {
      return $file_uri;
    }

    // Try and load the given image style.
    try {
      if ($image_style != '') {
        if ($is = $this->entityTypeManager->getStorage('image_style')->load($image_style)) {
          return $is->buildUrl($file_uri);
        }
      }
    }
    catch (\Error $e) {
      $this->loggerChannel->error($e->getTraceAsString());

    }
    return \Drupal::service('file_url_generator')->generateAbsoluteString($file_uri);
  }

}
