<?php

namespace Drupal\Tests\acquia_dam\Kernel;

use Drupal\acquia_dam\Exception\DamClientException;
use GuzzleHttp\HandlerStack;
use Psr\Http\Message\UriInterface;

/**
 * Tests client factory client creation.
 *
 * @group acquia_dam
 */
class DamClientFactoryTest extends AcquiaDamKernelTestBase {

  /**
   * Tests that an exception is thrown if there is no user token.
   */
  public function testExceptionWithoutToken(): void {
    $this->expectException(DamClientException::class);
    $this->expectExceptionMessage('Cannot get Acquia DAM token for client instantiation.');
    $client_factory = $this->container->get('acquia_dam.client.factory');
    $client_factory->getSiteClient();
    $this->expectException(DamClientException::class);
    $this->expectExceptionMessage('Cannot get Acquia DAM token for client instantiation.');
    $client_factory->getUserClient(FALSE);
  }

  /**
   * Tests the client created with client factory.
   *
   * @throws \Exception
   */
  public function testClient() {
    $user = $this->drupalSetUpCurrentUser();
    $client_factory = $this->container->get('acquia_dam.client.factory');
    $client = $client_factory->getUserClient();

    /** @var array<string, mixed> $config */
    $config = $client->getConfig();
    $this->assertNotEmpty($config);
    $this->assertNotEmpty($config['base_uri']);

    $base_uri = $config['base_uri'];
    self::assertInstanceOf(UriInterface::class, $base_uri);
    $this->assertEquals('api.widencollective.com', $base_uri->getHost());
    $this->assertEquals('https', $base_uri->getScheme());

    $this->assertNotEmpty($config['headers']);
    $this->assertNotEmpty($config['headers']['Authorization']);
    $this->assertNotEmpty($config['headers']['Content-Type']);
    $this->assertNotEmpty($config['handler']);

    $token = $this->container->get('acquia_dam.authentication_service')
      ->getUserData($user->id());
    self::assertArrayHasKey('acquia_dam_token', $token);
    $this->assertEquals('Bearer ' . $token['acquia_dam_token'], $config['headers']['Authorization']);
    $this->assertEquals('application/json', $config['headers']['Content-Type']);
    $this->assertInstanceOf(HandlerStack::class, $config['handler']);

    $this->setDamSiteToken();

    $client = $client_factory->getSiteClient();
    $config = $client->getConfig();
    $token = $this->container->get('state')->get('acquia_dam_token');

    $this->assertEquals('Bearer ' . $token, $config['headers']['Authorization']);
  }

}
