<?php

namespace src\Kernel;

use Drupal\field\Entity\FieldConfig;
use Drupal\field\Entity\FieldStorageConfig;
use Drupal\media\Entity\Media;
use Drupal\Tests\acquia_dam\Kernel\AcquiaDamKernelTestBase;
use function PHPUnit\Framework\assertEquals;

/**
 * Tests asset version update with media_acquiadam.
 *
 * @group acquia_dam
 */
class MediaSourceAssetMapTest extends AcquiaDamKernelTestBase {
  /**
   * {@inheritdoc}
   */
  protected static $modules = [
    'acquia_dam_test',
  ];

  /**
   * Tests Media metadata mapping.
   */
  public function testMetadataMapWithVersion() {
    $this->drupalSetUpCurrentUser();
    $this->setDamSiteToken();
    $this->grantDamDomain();

    $configFactory = $this->container->get('config.factory');
    $configFactory->getEditable('acquia_dam.settings')
      ->set('allowed_metadata', ['assettype'])
      ->save();
    $media_type = $this->createImageMediaType();

    $field_storage = FieldStorageConfig::create([
      'entity_type' => 'media',
      'field_name' => 'drupal_asset_type',
      'type' => 'string',
    ]);

    FieldConfig::create([
      'field_storage' => $field_storage,
      'bundle' => $media_type->id(),
      'label' => 'Asset Type',
    ])->save();
    $field_storage->save();

    $media_type->setFieldMap([
      'assettype' => 'drupal_asset_type',
    ])->save();
    $media = Media::create([
      'bundle' => $media_type->id(),
      'name' => 'Wheel Illustration.ai',
      'acquia_dam_asset_id' => [
        'asset_id' => '56ff14de-02cd-41b5-9a73-c917eab19abf',
        'version_id' => '7b67948f-ee7e-405c-a0cd-344a24d8afb2',
      ],
    ]);
    $media->save();
    assertEquals('image', $media->get('drupal_asset_type')->getValue()[0]['value']);
    $media->set('drupal_asset_type', 'NEEDS_UPDATE');
    $this->container->get('cron')->run();

    // Reload media instance after cron run.
    $media = $this->reloadEntity($media);
    $updated_version_id = $media->get('acquia_dam_asset_id')->version_id;
    self::assertEquals('9e4e810c-147b-4ac2-85a9-cf64f8fa61e0', $updated_version_id);
    assertEquals('image', $media->get('drupal_asset_type')->getValue()[0]['value']);
  }

}
